translate.misc.progressbar.MessageProgressBar

Package translate :: Package misc :: Module progressbar :: Class MessageProgressBar |
[hide private]
[frames] | no frames]

# Class MessageProgressBar

source code

a ProgressBar that just writes out the messages without any progress display

Instance Methods | [hide private]
__init__(self, *args, **kwargs) | source code
show(self, verbosemessage) displays the progress bar | source code
Inherited from `ProgressBar`: `__str__`

Method Details | [hide private]

### __init__(self, *args, **kwargs) (Constructor) | source code
Overrides: ProgressBar.__init__

### show(self, verbosemessage) | source code
displays the progress bar Overrides: ProgressBar.show (inherited documentation)